@@ -516,7 +516,8 @@ coxpenal.fit <- function(x, y, strata, offset, init, control,
 		 residuals = resid,
 		 means = means,
                  concordance= survConcordance.fit(y, lp, strata, weights),
-		 method= c('coxph.penal', 'coxph'),
+                 method = method,
+		 class = c('coxph.penal', 'coxph'),
 		 frail = coxfit$fcoef,
 		 fvar  = dftemp$fvar,
 		 df = df, df2=dftemp$df2, 
@@ -533,7 +534,8 @@ coxpenal.fit <- function(x, y, strata, offset, init, control,
 		 residuals = resid,
 		 means = means,
                  concordance= survConcordance.fit(y, lp, strata, weights),
-		 method= c('coxph.penal', 'coxph'),
+                 method = method, 
+		 class = c('coxph.penal', 'coxph'),
 		 frail = coxfit$fcoef,
 		 fvar  = dftemp$fvar,
 		 df = df, df2=dftemp$df2, 
@@ -553,7 +555,8 @@ coxpenal.fit <- function(x, y, strata, offset, init, control,
 	     residuals = resid,
 	     means = means,
              concordance= survConcordance.fit(y, lp, strata, weights),
-	     method= c('coxph.penal', 'coxph'),
+             method = method,
+	     class = c('coxph.penal', 'coxph'),
 	     df = df, df2=dftemp$df2,
 	     penalty= c(penalty0, penalty), 
 	     pterms = pterms, assign2=assign,
